/***************************************************************************
                          knutmessagemanager.cpp  -  description
                             -------------------
    begin                : So led 24 2004
    copyright            : (C) 2004 by Daniel Prynych
    email                : Daniel at prynych.cz
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "knutmessagemanager.h"
#include <KDE/KNotification>
#include <KDE/KLocale>
#include <KDE/KIcon>

#include <QtGui/QPixmap>
#include <QtCore/QString>
#include <QtCore/QTimer>

#include <QMutexLocker>

//#include <iostream>

KNutMessageManager::KNutMessageManager(  QObject *parent ) : QObject (parent) {
qDebug("KNutMessageManager::KNutMessageManager");

  m_message =0; // pointer of popup message
  m_messageLevel = noneLevel;

  loadPixmap();
  m_messageTimer = new QTimer(this);
  }



KNutMessageManager::~KNutMessageManager(){

  deleteMessage ();
  }


void KNutMessageManager::closeMessages(void){
qDebug("KNutMessageManager::closeMessages");
  deleteMessage ();
  }


void KNutMessageManager::loadPixmap (void) {

  m_infoPixmap = KIcon("messagebox_info").pixmap(QSize(16,16));
  m_warningPixmap = KIcon("messagebox_warning").pixmap(QSize(16,16));
  m_criticalPixmap = KIcon("messagebox_critical").pixmap(QSize(16,16));
}


void KNutMessageManager::startTimer ( long timeOfMessageValidity ) {
  m_messageTimer->start(timeOfMessageValidity);
  connect (m_messageTimer,SIGNAL(timeout()),this,SLOT(slotTimeout()));
}



void KNutMessageManager::deleteMessage (void) {
qDebug ("KNutMessageManager::deleteMessage");
  QMutexLocker upsDeleteLocker( &m_mutex );
  m_messageTimer->stop();
  if (m_message ) {
    disconnect (m_message,SIGNAL(closed()),this,SLOT(slotFinishedMessage()));
    disconnect (m_messageTimer,SIGNAL(timeout()),this,SLOT(slotTimeout()));
    // m_message->close();  //close a delete instance of KNotification
    delete m_message;
    m_message = 0;
    m_messageLevel = noneLevel;
    }
  }


void KNutMessageManager::addMessage (QString text, LevelOfMessage messageLevel, bool useShortTimeOfValidity, bool closePrevMessage ) {
long int timeOfMessageValidity;
qDebug ("KNutMessageManager::addMessage");


  if ((!(messageLevel < m_messageLevel)) || closePrevMessage) {

    if (useShortTimeOfValidity) timeOfMessageValidity = ShortTimeOfValidity;
    else timeOfMessageValidity = TimeOfValidity;
 
    deleteMessage();

    m_message= new KNotification ( "info_event",0L,KNotification::Persistent );
    m_message->setText(text);

      switch (messageLevel) {
        case noneLevel:
          break;
        case infoLevel:
          m_message->setPixmap( m_infoPixmap );
          break;
        case warningLevel:
          m_message->setPixmap( m_warningPixmap );
          break;
        case errorLevel:
        case criticalLevel:
          m_message->setPixmap( m_criticalPixmap );
          break;
        }

    m_messageLevel=messageLevel;
    connect (m_message,SIGNAL(closed()),this,SLOT(slotFinishedMessage()));

    startTimer(timeOfMessageValidity);

qDebug ("KNutMessageManager::sendEvent");
QTimer::singleShot(10,m_message,SLOT(sendEvent()));
//    m_message->sendEvent(); //fires text
    }
  }


void KNutMessageManager::slotFinishedMessage (void) {

qDebug("KNutMessageManager::slotFinishedMessage");
  m_messageTimer->stop();
  m_message=0L;
  m_messageLevel = noneLevel;
  }

void KNutMessageManager::slotTimeout (void) {
qDebug ("KNutMessageManager::slotTimeout");
 //kdyz vyprsi doba platnosti (timeValidity)

  deleteMessage();
  }



#include "knutmessagemanager.moc"
