/***************************************************************************
                          knutmessagemanager.h  -  description
                             -------------------
    begin                : So led 24 2004
    copyright            : (C) 2004 by Daniel Prynych
    email                : Daniel@prynych.cz
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KNUTMESSAGEMANAGER_H
#define KNUTMESSAGEMANAGER_H

#include <KDE/KNotification>
#include <KDE/KLocale>

//#include <QtGui/QPixmap>
 #include <QMutex>

#include <qobject.h>

/**
  *@author Daniel Prynych
  */

class QTimer;
class QString;
class QPixmap;

/**
 * Tato trida slouzi pro ovladani vyskakovacich oken (pop-up)
 * Okno pracuji nezavisle na ostatnich oknech a NEPOZASTAVUJI jejich cinnost.
 *
 * @author Daniel Prynych
 * @short window message manager
 * @version 0.1
  */
class KNutMessageManager : public QObject  {
    Q_OBJECT
  public:

enum LevelOfMessage {
  noneLevel,    // none for internal reason
  infoLevel,    // status RB, TRIM, CAL, TRIM
  warningLevel, // status  OB LB..
  errorLevel,   // connection error
  criticalLevel // Status BL, OFF
  };


/**
 * Konstruktor - vytvori instanci tridy.
 * Constructor - makes instance of class
 *
 * @since  0.1
 */
  KNutMessageManager(  QObject *parent=0);

/**
 * Destruktor.
 *
 * @since  0.1.1
 **/
  ~KNutMessageManager();

/**
 *
 * Loads pixmaps for popupmessages
 * @since 0.1
 **/
  void loadPixmap (void);


/**
 * Pozada o zobrazeni okna. Pokud je zobrazeno okne s vyssi prioritou, neni funkce provedena.
 *
 * @param  text Text of message, which will be showed in window
 * 
 * @param  text Text zpravy ktera se zobrazi v okne.
 * @param messageLevel urcuje prioritu zpravy.
 * @param closePrevMessage Urcuje zda se ma smazat prechazejici zprava pokud existuje.
 *
 * @since  0.2
 **/
  void addMessage (QString text, LevelOfMessage messageLevel = infoLevel, bool useShortTimeOfValidity = false,  bool closePrevMessage = false );


/**
 * Closes message popup windows / windows
 *
 * @since  0.1
 **/ 
  void closeMessages(void);


  private slots:

/**
 * @internal
 * Je aktivovan, kdyz bylo pozadano o zruseni okna stisknutim praveho widgetu nebo vnejsimi udalostmi (KDE Logout).
 *
 * @since  0.1.2
 **/
  void slotFinishedMessage (void);

/**
 * @internal
 * Je aktivovan, kdyz bylo pozadano o zruseni okna  vyprsenim casoveho terminu
 *
 * @since  0.1.2
 **/
  void slotTimeout (void);


  private:
  static const long int TimeOfValidity = 120000; //120 sec or 2 min
  static const long int ShortTimeOfValidity = 20000; // 20 sec


  void startTimer (long timeOfMessageValidity);


/**
 * Close window, when one is existed 
 * Zrusi okno, pokud existuje;
 *
 * @since  0.1.1
 **/
  void deleteMessage (void);


  KNotification* m_message;
 
  LevelOfMessage m_messageLevel;

  QPixmap  m_infoPixmap;
  QPixmap  m_warningPixmap;
  QPixmap  m_criticalPixmap;

  QTimer *m_messageTimer;

  QMutex m_mutex;


  };

#endif
